# Spice.ai v0.3.1-alpha

We are excited to announce the release of Spice.ai v0.3.1-alpha! 🎃

This point release focuses on fixes and improvements to v0.3-alpha. Highlights include the ability to specify both seed and runtime data, to select custom named fields for `time` and `tags`, a new `spice upgrade` command and several bug fixes.

A special acknowledgment to [@Adm28](https://github.com/Adm28), who added the new `spice upgrade` command, which enables the CLI to self-update, which in turn will auto-update the runtime.

## Highlights in v0.3.1-alpha

### Upgrade command

The CLI can now be updated using the new `spice upgrade` command. This command will check for, download, and install the latest Spice.ai CLI release, which will become active on it's next run.

When run, the CLI will check for the matching version of the Spice.ai runtime, and will automatically download and install it as necessary.

The version of both the Spice.ai CLI and runtime can be checked with the `spice version` CLI command.

### Seed data

When working with streaming data sources, like market prices, it's often also useful to seed the dataspace with historical data. Spice.ai enables this with the new `seed_data` node in the dataspace configuration. The syntax is exactly the same as the `data` syntax. For example:

```yaml
dataspaces:
  - from: coinbase
    name: btcusd
    seed_data:
      connector: file
        params:
          path: path/to/seed/data.csv
      processor:
        name: csv
    data:
      connector: coinbase
        params:
          product_ids: BTC-USD
      processor:
        name: json
```

The seed data will be fetched first, before the runtime data is initialized. Both sets of connectors and processors use the dataspace scoped `measurements`, `categories` and `tags` for processing, and both data sources are merged in pod-scoped observation timeline.

### Time field selectors

Before v0.3.1-alpha, data was required to include a specific `time` field. In v0.3.1-alpha, the [JSON](https://github.com/spiceai/data-components-contrib/blob/trunk/dataprocessors/json/README.md) and [CSV](https://github.com/spiceai/data-components-contrib/tree/trunk/dataprocessors/csv) data processors now support the ability to select a specific field to populate the time field. An example selector to use the `created_at` column for `time` is:

```yaml
data:
   processor:
      name: csv
      params:
        time_selector: created_at
```

### Tag field selectors

Before v0.3.1-alpha, [tags](https://docs.spiceai.org/reference/pod/#dataspacestags) were required to be placed in a `_tags` field. In v0.3.1-alpha, any field can now be selected to populate tags. Tags are pod-unique string values, and the union of all selected fields will make up the resulting tag list. For example:

```yaml
dataspace:
  from: twitter
  name: tweets
  tags:
    selectors:
      - tags
      - author_id
    values:
      - spiceaihq
      - spicy
```

## New in this release

- **Adds** a new `spice upgrade` command for self-upgrade of the Spice.ai CLI.
- **Adds** a new `seed_data` node to the dataspace configuration, enabling the dataspace to be seeded with an alternative source of data.
- **Adds** the ability to select a custom time field in JSON and CSV data processors with the `time_selector` parameter.
- **Adds** the ability to select custom tag fields in the dataspace configuration with `selectors` list.
- **Adds** error reporting for AI engine crashes, where previously it would fail silently.
- **Fixes** the dashboard pods list from "jumping" around due to being unsorted.
- **Fixes** rare cases where categorical data might be sent to the AI engine in the wrong format.